@@ -105,8 +105,8 @@ class SlappResponseObject:
                 if player_dict and player_dict.get("Item1") and (player_dict["Item2"] or include_ex_players)]
 
     def get_teams_for_player(self, p: Player) -> List[Team]:
-        from slapp_py.core_classes.builtins import NoTeam, UNKNOWN_TEAM
-        return list(map(lambda t: self.known_teams.get(t, UNKNOWN_TEAM) if t != NoTeam.guid else NoTeam, p.teams))
+        from slapp_py.core_classes.builtins import NoTeam, UnknownTeam
+        return list(map(lambda t: self.known_teams.get(t, UnknownTeam) if t != NoTeam.guid else NoTeam, p.teams))
 
     def get_team_skills(self, team_guid: Union[UUID, str], include_ex_players: bool = True) -> Dict[Player, Skill]:
         """
